{% extends "base.html" %}
{% load static %}

{% block extra_css %}
    <link rel="stylesheet" href="{% static 'css/reactify  .css' %}">
{% endblock extra_css %}

{% block content %}{% endblock content %}

{% block extra_js %}
<script src="{% static 'js/main.js' %}"></script>
{% endblock %}
